
From: Prasanna S Panchamukhi <prasanna@in.ibm.com>

Several aggregate kprobe handlers and return probe routines were
unnecessarily made global.  This patch moves several global routines to
static.

Signed-off-by: Prasanna S Panchamukhi <prasanna@in.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 kernel/kprobes.c |   15 ++++++++-------
 1 files changed, 8 insertions(+), 7 deletions(-)

diff -puN kernel/kprobes.c~kprobes-move-aggregate-probe-handlers-and-few-return-probe-routines-to-static kernel/kprobes.c
--- 25/kernel/kprobes.c~kprobes-move-aggregate-probe-handlers-and-few-return-probe-routines-to-static	2005-06-08 22:41:06.000000000 -0700
+++ 25-akpm/kernel/kprobes.c	2005-06-08 22:41:06.000000000 -0700
@@ -82,7 +82,7 @@ struct kprobe *get_kprobe(void *addr)
  * Aggregate handlers for multiple kprobes support - these handlers
  * take care of invoking the individual kprobe handlers on p->list
  */
-int aggr_pre_handler(struct kprobe *p, struct pt_regs *regs)
+static int aggr_pre_handler(struct kprobe *p, struct pt_regs *regs)
 {
 	struct kprobe *kp;
 
@@ -96,8 +96,8 @@ int aggr_pre_handler(struct kprobe *p, s
 	return 0;
 }
 
-void aggr_post_handler(struct kprobe *p, struct pt_regs *regs,
-		unsigned long flags)
+static void aggr_post_handler(struct kprobe *p, struct pt_regs *regs,
+			      unsigned long flags)
 {
 	struct kprobe *kp;
 
@@ -111,7 +111,8 @@ void aggr_post_handler(struct kprobe *p,
 	return;
 }
 
-int aggr_fault_handler(struct kprobe *p, struct pt_regs *regs, int trapnr)
+static int aggr_fault_handler(struct kprobe *p, struct pt_regs *regs,
+			      int trapnr)
 {
 	/*
 	 * if we faulted "during" the execution of a user specified
@@ -139,7 +140,7 @@ struct kretprobe_instance *get_free_rp_i
 	return NULL;
 }
 
-struct kretprobe_instance *get_used_rp_inst(struct kretprobe *rp)
+static struct kretprobe_instance *get_used_rp_inst(struct kretprobe *rp)
 {
 	struct hlist_node *node;
 	struct kretprobe_instance *ri;
@@ -235,7 +236,7 @@ void kprobe_flush_task(struct task_struc
  * This kprobe pre_handler is registered with every kretprobe. When probe
  * hits it will set up the return probe.
  */
-int pre_handler_kretprobe(struct kprobe *p, struct pt_regs *regs)
+static int pre_handler_kretprobe(struct kprobe *p, struct pt_regs *regs)
 {
 	struct kretprobe *rp = container_of(p, struct kretprobe, kp);
 
@@ -244,7 +245,7 @@ int pre_handler_kretprobe(struct kprobe 
 	return 0;
 }
 
-inline void free_rp_inst(struct kretprobe *rp)
+static inline void free_rp_inst(struct kretprobe *rp)
 {
 	struct kretprobe_instance *ri;
 	while ((ri = get_free_rp_inst(rp)) != NULL) {
_
